@@ -1,19 +1,21 @@
 import json
+import os
+from os import path
 import pandas as pd
 import time
 import LibHanger.Library.uwLogger as Logger
-import chromedriver_binary # コメントアウトしないこと
+#import chromedriver_binary # コメントアウトしないこと
 from pandas.core.frame import DataFrame 
 from selenium import webdriver
 from selenium.webdriver.android.webdriver import WebDriver
 from selenium.webdriver.chrome.options import Options
-from bs4 import BeautifulSoup, element
+from bs4 import BeautifulSoup
 from mercariGetter.Library.mercariConfig import mercariConfig
 from LibHanger.Library.uwGlobals import *
 from mercariGetter.Library.mercariException import resultDataGenerateError
 from selenium.webdriver.common.by import By
-from selenium.webdriver.support.ui import WebDriverWait
-from selenium.webdriver.support import expected_conditions as EC
+#from selenium.webdriver.support.ui import WebDriverWait
+#from selenium.webdriver.support import expected_conditions as EC
 
 class mercariDataSearch:
     
@@ -109,7 +111,9 @@ class mercariDataSearch:
 
         options = Options()
         options.add_argument('--headless')
-        return webdriver.Chrome(options=options)
+        #return webdriver.Chrome(options=options)
+        driverPath = os.path.join(path.dirname(__file__), 'webDriver','win','chromedriver_win32','chromedriver.exe')
+        return webdriver.Chrome(executable_path=driverPath, options=options)
 
     @Logger.loggerDecorator('Changing Browzer Size')
     def changeBrowzerSize(self, driver:WebDriver, width:str, height:str):
